@@ -26,6 +26,35 @@ class EsClient(AbstractClient):
     _service = 'es'
 
 
+    def CreateIndex(self, request):
+        """This API is used to create indices.
+
+        :param request: Request instance for CreateIndex.
+        :type request: :class:`tencentcloud.es.v20180416.models.CreateIndexRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.CreateIndexResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateIndex", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateIndexResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateInstance(self, request):
         """This API is used to create an ES cluster instance with the specified specification.
 
@@ -55,6 +84,35 @@ class EsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DeleteIndex(self, request):
+        """This API is used to delete indices.
+
+        :param request: Request instance for DeleteIndex.
+        :type request: :class:`tencentcloud.es.v20180416.models.DeleteIndexRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DeleteIndexResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteIndex", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DeleteIndexResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DeleteInstance(self, request):
         """This API is used to terminate a cluster instance.
 
@@ -84,6 +142,64 @@ class EsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeIndexList(self, request):
+        """This API is used to obtain the index list.
+
+        :param request: Request instance for DescribeIndexList.
+        :type request: :class:`tencentcloud.es.v20180416.models.DescribeIndexListRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DescribeIndexListResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeIndexList", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeIndexListResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeIndexMeta(self, request):
+        """This API is used to obtain index metadata.
+
+        :param request: Request instance for DescribeIndexMeta.
+        :type request: :class:`tencentcloud.es.v20180416.models.DescribeIndexMetaRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.DescribeIndexMetaResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeIndexMeta", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeIndexMetaResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeInstanceLogs(self, request):
         """This API is used to query the eligible ES cluster logs in the current region.
 
@@ -345,6 +461,35 @@ class EsClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def UpdateIndex(self, request):
+        """This API is used to update indices.
+
+        :param request: Request instance for UpdateIndex.
+        :type request: :class:`tencentcloud.es.v20180416.models.UpdateIndexRequest`
+        :rtype: :class:`tencentcloud.es.v20180416.models.UpdateIndexResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("UpdateIndex", params, headers=headers)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UpdateIndexResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateInstance(self, request):
         """This API is used for operations such as modifying node specification, renaming an instance, modifying configuration, resetting password, and setting Kibana blocklist/allowlist. `InstanceId` is required, while `ForceRestart` is optional. Other parameters or parameter combinations and their meanings are as follows:
         - InstanceName: renames an instance (only for instance identification)
