@@ -14,6 +14,9 @@
 # limitations under the License.
 
 
+# The operation failed as the account has been suspended due to overdue payments.
+FAILEDOPERATION_ACCOUNTISOLATED = 'FailedOperation.AccountIsolated'
+
 # This device has been transferred and cannot be created again.
 FAILEDOPERATION_ALREADYDISTRIBUTIONDEVICE = 'FailedOperation.AlreadyDistributionDevice'
 
@@ -23,6 +26,9 @@ FAILEDOPERATION_TIDWHITELISTNOTOPEN = 'FailedOperation.TidWhiteListNotOpen'
 # Internal error.
 INTERNALERROR = 'InternalError'
 
+# An internal database error occurred.
+INTERNALERROR_DBOPERATIONERROR = 'InternalError.DBOperationError'
+
 # Parameter error.
 INVALIDPARAMETER = 'InvalidParameter'
 
@@ -53,7 +59,7 @@ INVALIDPARAMETERVALUE_TIDPRODUCTALREADYEXIST = 'InvalidParameterValue.TidProduct
 # Unable to operate because the CA certificate is already bound to a product.
 LIMITEXCEEDED_CAALREADYBINDPRODUCT = 'LimitExceeded.CAAlreadyBindProduct'
 
-# 
+# The certificate name already exists.
 LIMITEXCEEDED_CACERTNAMEREPEAT = 'LimitExceeded.CACertNameRepeat'
 
 # The CA certificate already exists.
@@ -71,12 +77,18 @@ RESOURCENOTFOUND_CACERTNOTEXIST = 'ResourceNotFound.CACertNotExist'
 # The device does not exist.
 RESOURCENOTFOUND_DEVICENOTEXIST = 'ResourceNotFound.DeviceNotExist'
 
+# The device shadow does not exist.
+RESOURCENOTFOUND_DEVICESHADOWNOTEXIST = 'ResourceNotFound.DeviceShadowNotExist'
+
 # The product does not exist.
 RESOURCENOTFOUND_PRODUCTNOTEXIST = 'ResourceNotFound.ProductNotExist'
 
 # The TSL model does not exist.
 RESOURCENOTFOUND_THINGMODELNOTEXIST = 'ResourceNotFound.ThingModelNotExist'
 
+# There is already a TID application for this product, so it cannot be deleted.
+UNAUTHORIZEDOPERATION_DELETETIDFAIL = 'UnauthorizedOperation.DeleteTidFail'
+
 # Unable to delete this device as gateway devices have been bound to it.
 UNAUTHORIZEDOPERATION_DEVICEHASALREADYBINDGATEWAY = 'UnauthorizedOperation.DeviceHasAlreadyBindGateway'
 
