@@ -158,6 +158,9 @@ RESOURCEINUSE = 'ResourceInUse'
 # Insufficient resource.
 RESOURCEINSUFFICIENT = 'ResourceInsufficient'
 
+# Insufficient balance.
+RESOURCEINSUFFICIENT_BALANCE = 'ResourceInsufficient.Balance'
+
 # The resource does not exist.
 RESOURCENOTFOUND = 'ResourceNotFound'
 
