@@ -36,7 +36,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateTranscode", params)
+            headers = request.headers
+            body = self.call("CreateTranscode", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateTranscodeResponse()
@@ -64,7 +65,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeOnlineRecord", params)
+            headers = request.headers
+            body = self.call("DescribeOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeOnlineRecordResponse()
@@ -92,7 +94,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeOnlineRecordCallback", params)
+            headers = request.headers
+            body = self.call("DescribeOnlineRecordCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeOnlineRecordCallbackResponse()
@@ -120,7 +123,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTranscode", params)
+            headers = request.headers
+            body = self.call("DescribeTranscode", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTranscodeResponse()
@@ -148,7 +152,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeTranscodeCallback", params)
+            headers = request.headers
+            body = self.call("DescribeTranscodeCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DescribeTranscodeCallbackResponse()
@@ -176,7 +181,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("PauseOnlineRecord", params)
+            headers = request.headers
+            body = self.call("PauseOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.PauseOnlineRecordResponse()
@@ -204,7 +210,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ResumeOnlineRecord", params)
+            headers = request.headers
+            body = self.call("ResumeOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ResumeOnlineRecordResponse()
@@ -232,7 +239,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetOnlineRecordCallback", params)
+            headers = request.headers
+            body = self.call("SetOnlineRecordCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetOnlineRecordCallbackResponse()
@@ -260,7 +268,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetOnlineRecordCallbackKey", params)
+            headers = request.headers
+            body = self.call("SetOnlineRecordCallbackKey", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetOnlineRecordCallbackKeyResponse()
@@ -288,7 +297,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetTranscodeCallback", params)
+            headers = request.headers
+            body = self.call("SetTranscodeCallback", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetTranscodeCallbackResponse()
@@ -316,7 +326,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SetTranscodeCallbackKey", params)
+            headers = request.headers
+            body = self.call("SetTranscodeCallbackKey", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SetTranscodeCallbackKeyResponse()
@@ -344,7 +355,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StartOnlineRecord", params)
+            headers = request.headers
+            body = self.call("StartOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StartOnlineRecordResponse()
@@ -372,7 +384,8 @@ class TiwClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("StopOnlineRecord", params)
+            headers = request.headers
+            body = self.call("StopOnlineRecord", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.StopOnlineRecordResponse()
