@@ -50,6 +50,9 @@ FAILEDOPERATION_MEDIATYPE = 'FailedOperation.MediaType'
 # Network error.
 FAILEDOPERATION_NETWORKERROR = 'FailedOperation.NetWorkError'
 
+# No need to reduce the bitrate.
+FAILEDOPERATION_NONEEDTOREDUCEMEDIABITRATE = 'FailedOperation.NoNeedToReduceMediaBitrate'
+
 # Operation failed: the parent category ID does not exist.
 FAILEDOPERATION_PARENTIDNOFOUND = 'FailedOperation.ParentIdNoFound'
 
@@ -197,6 +200,9 @@ INVALIDPARAMETERVALUE_COVERTYPE = 'InvalidParameterValue.CoverType'
 # Incorrect parameter value: cover URL.
 INVALIDPARAMETERVALUE_COVERURL = 'InvalidParameterValue.CoverUrl'
 
+# Parameter error: Invalid `CutAndCrops` value.
+INVALIDPARAMETERVALUE_CUTANDCROPS = 'InvalidParameterValue.CutAndCrops'
+
 # Incorrect parameter value: time granularity.
 INVALIDPARAMETERVALUE_DATAINTERVAL = 'InvalidParameterValue.DataInterval'
 
@@ -521,6 +527,9 @@ INVALIDPARAMETERVALUE_TEXTALPHA = 'InvalidParameterValue.TextAlpha'
 # Invalid parameter: text template.
 INVALIDPARAMETERVALUE_TEXTTEMPLATE = 'InvalidParameterValue.TextTemplate'
 
+# Parameter error: Invalid `Thumbnail` value.
+INVALIDPARAMETERVALUE_THUMBNAILS = 'InvalidParameterValue.Thumbnails'
+
 # Incorrect parameter value: TimeType.
 INVALIDPARAMETERVALUE_TIMETYPE = 'InvalidParameterValue.TimeType'
 
@@ -563,6 +572,9 @@ INVALIDPARAMETERVALUE_VIDS = 'InvalidParameterValue.Vids'
 # Incorrect parameter value: VOD session.
 INVALIDPARAMETERVALUE_VODSESSIONKEY = 'InvalidParameterValue.VodSessionKey'
 
+# Parameter error: Invalid `Watermarks` value.
+INVALIDPARAMETERVALUE_WATERMARKS = 'InvalidParameterValue.Watermarks'
+
 # Invalid parameter: width.
 INVALIDPARAMETERVALUE_WIDTH = 'InvalidParameterValue.Width'
 
